==> dde-dock_5.4.10.orig.tar.xz: dde-dock-5.4.10/translations/dde-dock_it.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="it" version="2.1">
<context>
    <name>AbstractPluginsController</name>
    <message>
        <source>The plugin %1 is not compatible with the system.</source>
        <translation>Il plugin %1 non risulta compatibile col Sistema.</translation>
    </message>
</context>
<context>
    <name>AppDragWidget</name>
    <message>
        <source>Remove</source>
        <translation>Rimuovi</translation>
    </message>
</context>
<context>
    <name>BluetoothApplet</name>
    <message>
        <source>Bluetooth settings</source>
        <translation>Impostazioni Bluetooth</translation>
    </message>
</context>
<context>
    <name>BluetoothItem</name>
    <message>
        <source>Turn off</source>
        <translation>Disattiva</translation>
    </message>
    <message>
        <source>Turn on</source>
        <translation>Attiva</translation>
    </message>
    <message>
        <source>Bluetooth settings</source>
        <translation>Impostazioni Bluetooth</translation>
    </message>
    <message>
        <source>%1 connected</source>
        <translation>%1 connesso</translation>
    </message>
    <message>
        <source>Connecting...</source>
        <translation>Connessione in corso...</translation>
    </message>
    <message>
        <source>Bluetooth</source>
        <translation>Bluetooth</translation>
    </message>
    <message>
        <source>Turned off</source>
        <translation>Disattivato</translation>
    </message>
</context>
<context>
    <name>BluetoothPlugin</name>
    <message>
        <source>Bluetooth</source>
        <translation>Bluetooth</translation>
    </message>
</context>
<context>
    <name>DBusAdaptors</name>
    <message>
        <source>Add keyboard layout</source>
        <translation>Aggiungi un layout della Tastiera</translation>
    </message>
</context>
<context>
    <name>DatetimePlugin</name>
    <message>
        <source>Datetime</source>
        <translation>Orologio</translation>
    </message>
    <message>
        <source>12-hour time</source>
        <translation>Formato 12 ore</translation>
    </message>
    <message>
        <source>24-hour time</source>
        <translation>Formato 24 ore</translation>
    </message>
    <message>
        <source>Time settings</source>
        <translation>Impostazioni orarie</translation>
    </message>
</context>
<context>
    <name>DeviceItem</name>
    <message>
        <source>Enable network</source>
        <translation>Abilita Rete</translation>
    </message>
    <message>
        <source>Disable network</source>
        <translation>Disabilita Rete</translation>
    </message>
    <message>
        <source>Network settings</source>
        <translation>Impostazioni Rete</translation>
    </message>
</context>
<context>
    <name>DialogManager</name>
    <message>
        <source>Are you sure you want to empty %1 items?</source>
        <translation>Sicuro di voler eliminare %1 elementi?</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Annulla</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Elimina</translation>
    </message>
    <message>
        <source>This action cannot be restored</source>
        <translation>Questa azione non può esser annullata</translation>
    </message>
</context>
<context>
    <name>DiskControlItem</name>
    <message>
        <source>Unknown device</source>
        <translation>Dispositivo sconosciuto</translation>
    </message>
    <message>
        <source>Unknown volume</source>
        <translation>Volume sconosciuto</translation>
    </message>
</context>
<context>
    <name>DiskMountPlugin</name>
    <message>
        <source>Disk</source>
        <translation>Disco</translation>
    </message>
    <message>
        <source>Open</source>
        <translation>Apri</translation>
    </message>
    <message>
        <source>Unmount all</source>
        <translation>Smonta tutto</translation>
    </message>
</context>
<context>
    <name>LauncherItem</name>
    <message>
        <source>Launcher</source>
        <translation>Launcher</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Exit Safe Mode</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Dock - Safe Mode</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>The Dock is in safe mode, please exit to show it properly</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>MenuWorker</name>
    <message>
        <source>Fashion Mode</source>
        <translation>Fashion</translation>
    </message>
    <message>
        <source>Efficient Mode</source>
        <translation>Efficient</translation>
    </message>
    <message>
        <source>Top</source>
        <translation>Sopra</translation>
    </message>
    <message>
        <source>Bottom</source>
        <translation>Sotto</translation>
    </message>
    <message>
        <source>Left</source>
        <translation>Sinistra</translation>
    </message>
    <message>
        <source>Right</source>
        <translation>Destra</translation>
    </message>
    <message>
        <source>Keep Shown</source>
        <translation>Mostra sempre</translation>
    </message>
    <message>
        <source>Keep Hidden</source>
        <translation>Lascia nascosta</translation>
    </message>
    <message>
        <source>Smart Hide</source>
        <translation>Nascondi automaticamente</translation>
    </message>
    <message>
        <source>Mode</source>
        <translation>Modalità</translation>
    </message>
    <message>
        <source>Location</source>
        <translation>Posizione</translation>
    </message>
    <message>
        <source>Status</source>
        <translation>Comportamento</translation>
    </message>
    <message>
        <source>Plugins</source>
        <translation>Plugin</translation>
    </message>
</context>
<context>
    <name>MultitaskingPlugin</name>
    <message>
        <source>Multitasking View</source>
        <translation>Vista Multitasking</translation>
    </message>
    <message>
        <source>Undock</source>
        <translation>Sgancia</translation>
    </message>
</context>
<context>
    <name>NetworkItem</name>
    <message>
        <source>Disable wired connection</source>
        <translation>Disattiva connessione cablata</translation>
    </message>
    <message>
        <source>Enable wired connection</source>
        <translation>Attiva connessione cablata</translation>
    </message>
    <message>
        <source>Disable wireless connection</source>
        <translation>Disattiva connessione WiFi</translation>
    </message>
    <message>
        <source>Enable wireless connection</source>
        <translation>Attiva connessione WiFi</translation>
    </message>
    <message>
        <source>Disable network</source>
        <translation>Disabilita Rete</translation>
    </message>
    <message>
        <source>Enable network</source>
        <translation>Abilita Rete</translation>
    </message>
    <message>
        <source>Network settings</source>
        <translation>Impostazioni Rete</translation>
    </message>
    <message>
        <source>Device disabled</source>
        <translation>Dispositivo disattivato</translation>
    </message>
    <message>
        <source>Wireless connection: %1</source>
        <translation>Connessione WiFi: %1</translation>
    </message>
    <message>
        <source>Wired connection: %1</source>
        <translation>Connessione cablata: %1</translation>
    </message>
    <message>
        <source>Not connected</source>
        <translation>Non connesso</translation>
    </message>
    <message>
        <source>Connecting</source>
        <translation>Connessione in corso</translation>
    </message>
    <message>
        <source>Connected but no Internet access</source>
        <translation>Connesso senza accesso ad internet</translation>
    </message>
    <message>
        <source>Network cable unplugged</source>
        <translation>Cavo di rete scollegato</translation>
    </message>
    <message>
        <source>Wireless Network</source>
        <translation>Rete wireless</translation>
    </message>
    <message>
        <source>Wired Network</source>
        <translation>Connessione cablata</translation>
    </message>
    <message>
        <source>Connection failed</source>
        <translation>Connessione fallita</translation>
    </message>
</context>
<context>
    <name>NetworkPlugin</name>
    <message>
        <source>Network</source>
        <translation>Rete</translation>
    </message>
    <message>
        <source>Wired Network</source>
        <translation>Connessione cablata</translation>
    </message>
    <message>
        <source>Wired Network %1</source>
        <translation>Connessione cablata %1</translation>
    </message>
</context>
<context>
    <name>OnboardPlugin</name>
    <message>
        <source>Onboard</source>
        <translation>Tastiera</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Impostazioni</translation>
    </message>
</context>
<context>
    <name>PowerPlugin</name>
    <message>
        <source>Power</source>
        <translation>Alimentazione</translation>
    </message>
    <message>
        <source>Power settings</source>
        <translation>Impostazioni Alimentazione</translation>
    </message>
    <message>
        <source>Capacity %1, %2 min remaining</source>
        <translation>Carica %1, %2 min. rimanenti</translation>
    </message>
    <message>
        <source>Capacity %1, %2 hr %3 min remaining</source>
        <translation>Carica %1, %2 ore e %3 min. rimanenti</translation>
    </message>
    <message>
        <source>Charging %1, %2 min until full</source>
        <translation>Carica %1, %2 min. per la carica completa</translation>
    </message>
    <message>
        <source>Charging %1, %2 hr %3 min until full</source>
        <translation>Carica %1, %2 ore e %3 min. per la carica completa</translation>
    </message>
    <message>
        <source>Charged</source>
        <translation>Carico</translation>
    </message>
    <message>
        <source>Capacity %1</source>
        <translation>Carica %1</translation>
    </message>
    <message>
        <source>Charging %1</source>
        <translation>In carica %1</translation>
    </message>
    <message>
        <source>Capacity %1 ...</source>
        <translation>Carica %1 ...</translation>
    </message>
    <message>
        <source>Capacity %1, fully charged</source>
        <translation>Carica completa %1</translation>
    </message>
</context>
<context>
    <name>ShowDesktopPlugin</name>
    <message>
        <source>Show Desktop</source>
        <translation>Mostra Desktop</translation>
    </message>
    <message>
        <source>Undock</source>
        <translation>Sgancia</translation>
    </message>
</context>
<context>
    <name>ShutdownPlugin</name>
    <message>
        <source>Power</source>
        <translation>Alimentazione</translation>
    </message>
    <message>
        <source>Shut down</source>
        <translation>Spegni</translation>
    </message>
    <message>
        <source>Suspend</source>
        <translation>Sospendi</translation>
    </message>
    <message>
        <source>Hibernate</source>
        <translation>Ibernazione</translation>
    </message>
    <message>
        <source>Lock</source>
        <translation>Blocca</translation>
    </message>
    <message>
        <source>Log out</source>
        <translation>Logout</translation>
    </message>
    <message>
        <source>Switch account</source>
        <translation>Cambia account</translation>
    </message>
    <message>
        <source>Power settings</source>
        <translation>Impostazioni Alimentazione</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>Riavvia</translation>
    </message>
</context>
<context>
    <name>SoundApplet</name>
    <message>
        <source>Device</source>
        <translation>Dispositivo</translation>
    </message>
</context>
<context>
    <name>SoundItem</name>
    <message>
        <source>Unmute</source>
        <translation>Abilita suoni</translation>
    </message>
    <message>
        <source>Mute</source>
        <translation>Muto</translation>
    </message>
    <message>
        <source>Sound settings</source>
        <translation>Impostazioni audio</translation>
    </message>
    <message>
        <source>Volume %1</source>
        <translation>Volume %1</translation>
    </message>
</context>
<context>
    <name>SoundPlugin</name>
    <message>
        <source>Sound</source>
        <translation>Audio</translation>
    </message>
</context>
<context>
    <name>TrashPlugin</name>
    <message>
        <source>Trash</source>
        <translation>Cestino</translation>
    </message>
    <message>
        <source>Trash - %1 file</source>
        <translation>Cestino - %1 file</translation>
    </message>
    <message>
        <source>Trash - %1 files</source>
        <translation>Cestino - %1 file</translation>
    </message>
</context>
<context>
    <name>TrashWidget</name>
    <message>
        <source>Open</source>
        <translation>Apri</translation>
    </message>
    <message>
        <source>Empty</source>
        <translation>Svuota</translation>
    </message>
</context>
<context>
    <name>TrayPlugin</name>
    <message>
        <source>System Tray</source>
        <translation>Tray di Sistema</translation>
    </message>
</context>
<context>
    <name>WirelessList</name>
    <message>
        <source>Wireless Network</source>
        <translation>Rete wireless</translation>
    </message>
    <message>
        <source>Wireless Network %1</source>
        <translation>Rete wireless %1</translation>
    </message>
</context>
</TS>

==> dde-dock_5.5.53.orig.tar.xz: dde-dock-5.5.53/translations/dde-dock_it.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="it">
<context>
    <name>AbstractPluginsController</name>
    <message>
        <source>The plugin %1 is not compatible with the system.</source>
        <translation>Il plugin %1 non risulta compatibile col Sistema.</translation>
    </message>
</context>
<context>
    <name>AirplaneModeApplet</name>
    <message>
        <source>Airplane Mode</source>
        <translation>Modalità aereo</translation>
    </message>
</context>
<context>
    <name>AirplaneModeItem</name>
    <message>
        <source>Airplane mode enabled</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Turn off</source>
        <translation>Disattiva</translation>
    </message>
    <message>
        <source>Turn on</source>
        <translation>Attiva</translation>
    </message>
    <message>
        <source>Airplane Mode settings</source>
        <translation>Gestione modalità aereo</translation>
    </message>
    <message>
        <source>Airplane mode disabled</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>AirplaneModePlugin</name>
    <message>
        <source>Airplane Mode</source>
        <translation>Modalità aereo</translation>
    </message>
</context>
<context>
    <name>AppDragWidget</name>
    <message>
        <source>Remove</source>
        <translation>Rimuovi</translation>
    </message>
</context>
<context>
    <name>BluetoothApplet</name>
    <message>
        <source>Bluetooth settings</source>
        <translation>Impostazioni Bluetooth</translation>
    </message>
</context>
<context>
    <name>BluetoothItem</name>
    <message>
        <source>Turn off</source>
        <translation>Disattiva</translation>
    </message>
    <message>
        <source>Turn on</source>
        <translation>Attiva</translation>
    </message>
    <message>
        <source>Bluetooth settings</source>
        <translation>Impostazioni Bluetooth</translation>
    </message>
    <message>
        <source>%1 connected</source>
        <translation>%1 connesso</translation>
    </message>
    <message>
        <source>Connecting...</source>
        <translation>Connessione in corso...</translation>
    </message>
    <message>
        <source>Bluetooth</source>
        <translation>Bluetooth</translation>
    </message>
    <message>
        <source>Turned off</source>
        <translation>Disattivato</translation>
    </message>
</context>
<context>
    <name>BluetoothPlugin</name>
    <message>
        <source>Bluetooth</source>
        <translation>Bluetooth</translation>
    </message>
</context>
<context>
    <name>DBusAdaptors</name>
    <message>
        <source>Add keyboard layout</source>
        <translation>Aggiungi un layout della Tastiera</translation>
    </message>
</context>
<context>
    <name>DatetimePlugin</name>
    <message>
        <source>Datetime</source>
        <translation>Orologio</translation>
    </message>
    <message>
        <source>12-hour time</source>
        <translation>Formato 12 ore</translation>
    </message>
    <message>
        <source>24-hour time</source>
        <translation>Formato 24 ore</translation>
    </message>
    <message>
        <source>Time settings</source>
        <translation>Impostazioni orarie</translation>
    </message>
</context>
<context>
    <name>DialogManager</name>
    <message>
        <source>Are you sure you want to empty %1 items?</source>
        <translation>Sicuro di voler eliminare %1 elementi?</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Annulla</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Elimina</translation>
    </message>
    <message>
        <source>This action cannot be restored</source>
        <translation>Questa azione non può esser annullata</translation>
    </message>
</context>
<context>
    <name>DiskControlItem</name>
    <message>
        <source>Unknown device</source>
        <translation>Dispositivo sconosciuto</translation>
    </message>
    <message>
        <source>Unknown volume</source>
        <translation>Volume sconosciuto</translation>
    </message>
</context>
<context>
    <name>DiskMountPlugin</name>
    <message>
        <source>Disk</source>
        <translation>Disco</translation>
    </message>
    <message>
        <source>Open</source>
        <translation>Apri</translation>
    </message>
    <message>
        <source>Unmount all</source>
        <translation>Smonta tutto</translation>
    </message>
</context>
<context>
    <name>LauncherItem</name>
    <message>
        <source>Launcher</source>
        <translation>Launcher</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Exit Safe Mode</source>
        <translation>Esci dalla modalità provvisoria</translation>
    </message>
    <message>
        <source>Dock - Safe Mode</source>
        <translation>Dock - Modalità provvisoria</translation>
    </message>
    <message>
        <source>The Dock is in safe mode, please exit to show it properly</source>
        <translation>La Dock è in modalità provvisoria, esci per mostrarla in modo tradizionale</translation>
    </message>
</context>
<context>
    <name>MenuWorker</name>
    <message>
        <source>Fashion Mode</source>
        <translation>Fashion</translation>
    </message>
    <message>
        <source>Efficient Mode</source>
        <translation>Efficient</translation>
    </message>
    <message>
        <source>Top</source>
        <translation>Sopra</translation>
    </message>
    <message>
        <source>Bottom</source>
        <translation>Sotto</translation>
    </message>
    <message>
        <source>Left</source>
        <translation>Sinistra</translation>
    </message>
    <message>
        <source>Right</source>
        <translation>Destra</translation>
    </message>
    <message>
        <source>Keep Shown</source>
        <translation>Mostra sempre</translation>
    </message>
    <message>
        <source>Keep Hidden</source>
        <translation>Lascia nascosta</translation>
    </message>
    <message>
        <source>Smart Hide</source>
        <translation>Nascondi automaticamente</translation>
    </message>
    <message>
        <source>Mode</source>
        <translation>Modalità</translation>
    </message>
    <message>
        <source>Location</source>
        <translation>Posizione</translation>
    </message>
    <message>
        <source>Status</source>
        <translation>Comportamento</translation>
    </message>
    <message>
        <source>Dock settings</source>
        <translation>Impostazioni Dock</translation>
    </message>
</context>
<context>
    <name>ModuleWidget</name>
    <message>
        <source>Size</source>
        <translation>Dimensioni</translation>
    </message>
    <message>
        <source>Multiple Displays</source>
        <translation>Display multipli</translation>
    </message>
    <message>
        <source>Plugin Area</source>
        <translation>Area plugin</translation>
    </message>
    <message>
        <source>Select which icons appear in the Dock</source>
        <translation>Seleziona quali icone appaiono nel Dock</translation>
    </message>
    <message>
        <source>Fashion mode</source>
        <translation>Modalità Fashion</translation>
    </message>
    <message>
        <source>Efficient mode</source>
        <translation>Modalità Efficient</translation>
    </message>
    <message>
        <source>Mode</source>
        <translation>Modalità</translation>
    </message>
    <message>
        <source>Top</source>
        <translation>Top</translation>
    </message>
    <message>
        <source>Bottom</source>
        <translation>Sotto</translation>
    </message>
    <message>
        <source>Left</source>
        <translation>Sinistra</translation>
    </message>
    <message>
        <source>Right</source>
        <translation>Destra</translation>
    </message>
    <message>
        <source>Location</source>
        <translation>Posizione</translation>
    </message>
    <message>
        <source>Keep shown</source>
        <translation>Mostra sempre</translation>
    </message>
    <message>
        <source>Keep hidden</source>
        <translation>Nascondi sempre</translation>
    </message>
    <message>
        <source>Smart hide</source>
        <translation>Nascondi automaticamente</translation>
    </message>
    <message>
        <source>Status</source>
        <translation>Comportamento</translation>
    </message>
    <message>
        <source>Small</source>
        <translation>Piccolo</translation>
    </message>
    <message>
        <source>Large</source>
        <translation>Grande</translation>
    </message>
    <message>
        <source>Show Dock</source>
        <translation>Mostra la Dock</translation>
    </message>
    <message>
        <source>On screen where the cursor is</source>
        <translation>Sullo schermo dove è presente il cursore</translation>
    </message>
    <message>
        <source>Only on main screen</source>
        <translation>Solo sullo schermo principale</translation>
    </message>
</context>
<context>
    <name>MultitaskingPlugin</name>
    <message>
        <source>Multitasking View</source>
        <translation>Vista Multitasking</translation>
    </message>
    <message>
        <source>Undock</source>
        <translation>Sgancia</translation>
    </message>
</context>
<context>
    <name>OnboardPlugin</name>
    <message>
        <source>Onboard</source>
        <translation>Tastiera</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Impostazioni</translation>
    </message>
</context>
<context>
    <name>PowerPlugin</name>
    <message>
        <source>Power</source>
        <translation>Alimentazione</translation>
    </message>
    <message>
        <source>Power settings</source>
        <translation>Impostazioni Alimentazione</translation>
    </message>
    <message>
        <source>Capacity %1, %2 min remaining</source>
        <translation>Carica %1, %2 min. rimanenti</translation>
    </message>
    <message>
        <source>Capacity %1, %2 hr %3 min remaining</source>
        <translation>Carica %1, %2 ore e %3 min. rimanenti</translation>
    </message>
    <message>
        <source>Charging %1, %2 min until full</source>
        <translation>Carica %1, %2 min. per la carica completa</translation>
    </message>
    <message>
        <source>Charging %1, %2 hr %3 min until full</source>
        <translation>Carica %1, %2 ore e %3 min. per la carica completa</translation>
    </message>
    <message>
        <source>Capacity %1</source>
        <translation>Carica %1</translation>
    </message>
    <message>
        <source>Charging %1</source>
        <translation>In carica %1</translation>
    </message>
    <message>
        <source>Capacity %1 ...</source>
        <translation>Carica %1 ...</translation>
    </message>
    <message>
        <source>Capacity %1, fully charged</source>
        <translation>Carica completa %1</translation>
    </message>
</context>
<context>
    <name>SettingsModule</name>
    <message>
        <source>Dock</source>
        <translation>Dock</translation>
        <extra-contents_path>/personalization/Dock</extra-contents_path>
    </message>
</context>
<context>
    <name>ShowDesktopPlugin</name>
    <message>
        <source>Show Desktop</source>
        <translation>Mostra Desktop</translation>
    </message>
    <message>
        <source>Undock</source>
        <translation>Sgancia</translation>
    </message>
</context>
<context>
    <name>ShutdownPlugin</name>
    <message>
        <source>Power</source>
        <translation>Alimentazione</translation>
    </message>
    <message>
        <source>Shut down</source>
        <translation>Spegni</translation>
    </message>
    <message>
        <source>Suspend</source>
        <translation>Sospendi</translation>
    </message>
    <message>
        <source>Hibernate</source>
        <translation>Ibernazione</translation>
    </message>
    <message>
        <source>Lock</source>
        <translation>Blocca</translation>
    </message>
    <message>
        <source>Log out</source>
        <translation>Logout</translation>
    </message>
    <message>
        <source>Switch account</source>
        <translation>Cambia account</translation>
    </message>
    <message>
        <source>Power settings</source>
        <translation>Impostazioni Alimentazione</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>Riavvia</translation>
    </message>
</context>
<context>
    <name>SoundApplet</name>
    <message>
        <source>Device</source>
        <translation>Dispositivo</translation>
    </message>
</context>
<context>
    <name>SoundItem</name>
    <message>
        <source>Unmute</source>
        <translation>Abilita suoni</translation>
    </message>
    <message>
        <source>Mute</source>
        <translation>Muto</translation>
    </message>
    <message>
        <source>Sound settings</source>
        <translation>Impostazioni audio</translation>
    </message>
    <message>
        <source>Volume %1</source>
        <translation>Volume %1</translation>
    </message>
</context>
<context>
    <name>SoundPlugin</name>
    <message>
        <source>Sound</source>
        <translation>Audio</translation>
    </message>
</context>
<context>
    <name>TrashPlugin</name>
    <message>
        <source>Trash</source>
        <translation>Cestino</translation>
    </message>
    <message>
        <source>Trash - %1 file</source>
        <translation>Cestino - %1 file</translation>
    </message>
    <message>
        <source>Trash - %1 files</source>
        <translation>Cestino - %1 file</translation>
    </message>
    <message>
        <source>Move to Trash</source>
        <translation>Muovi nel cestino</translation>
    </message>
</context>
<context>
    <name>TrashWidget</name>
    <message>
        <source>Open</source>
        <translation>Apri</translation>
    </message>
    <message>
        <source>Empty</source>
        <translation>Svuota</translation>
    </message>
</context>
</TS>
